@@ -3,7 +3,7 @@
 import ctypes
 from typing import Optional, Tuple, Union
 
-from pydwf.core.dwf_library_subapi import DwfLibrarySubApi
+from pydwf.core.dwf_library_subapi import AbstractDwfLibrarySubApi
 
 from pydwf.core.auxiliary.enum_types import DwfEnumFilter, DwfEnumConfigInfo
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
@@ -11,7 +11,7 @@ from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
-class DeviceEnumeration(DwfLibrarySubApi):
+class DeviceEnumeration(AbstractDwfLibrarySubApi):
     """The |DeviceEnumeration| class provides access to the device enumeration functionality of a
     |DwfLibrary:link|.
 
@@ -52,7 +52,7 @@ class DeviceEnumeration(DwfLibrarySubApi):
         return device_count
 
     def deviceType(self, device_index: int) -> Tuple[int, int]:
-        """Return the device ID and version (revision) of the selected device.
+        """Return the device ID and version (hardware revision) of the selected device.
 
         Note:
             This function returns the integer values as reported by the *FDwfEnumDeviceType* function
@@ -71,8 +71,8 @@ class DeviceEnumeration(DwfLibrarySubApi):
         Raises:
             DwfLibraryError: The device type and version cannot be retrieved.
         """
-        c_device_id = typespec_ctypes.DEVID()
-        c_device_revision = typespec_ctypes.DEVVER()
+        c_device_id = typespec_ctypes.DwfDeviceID()
+        c_device_revision = typespec_ctypes.DwfDeviceVersion()
         result = self.lib.FDwfEnumDeviceType(device_index, c_device_id, c_device_revision)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -246,7 +246,7 @@ class DeviceEnumeration(DwfLibrarySubApi):
 
             * method :py:meth:`configInfo` to obtain the |DwfEnumConfigInfo.AnalogInChannelCount:link|
               configuration value;
-            * |DwfDevice.analogIn.channelCount:link|
+            * |AnalogIn.channelCount:link|
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
@@ -275,7 +275,7 @@ class DeviceEnumeration(DwfLibrarySubApi):
 
             * method :py:meth:`configInfo` to obtain the |DwfEnumConfigInfo.AnalogInBufferSize:link|
               configuration value;
-            * |DwfDevice.analogIn.bufferSizeGet:link|
+            * |AnalogIn.bufferSizeGet:link|
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
@@ -300,7 +300,7 @@ class DeviceEnumeration(DwfLibrarySubApi):
         Warning:
             This function is obsolete.
 
-            Use |DwfDevice.analogIn.bitsInfo:link| instead.
+            Use |AnalogIn.bitsInfo:link| instead.
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
@@ -325,7 +325,7 @@ class DeviceEnumeration(DwfLibrarySubApi):
         Warning:
             This function is obsolete.
 
-            Use |DwfDevice.analogIn.frequencyInfo:link| instead.
+            Use |AnalogIn.frequencyInfo:link| instead.
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
