@@ -2,7 +2,7 @@
 
 from typing import List, TYPE_CHECKING
 
-from pydwf.core.auxiliary.enum_types import DwfTriggerSource, DwfTriggerSlope, DwfParameter
+from pydwf.core.auxiliary.enum_types import DwfTriggerSource, DwfTriggerSlope, DwfDeviceParameter
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 
@@ -31,7 +31,7 @@ class DwfDevice:
 
         Users of |pydwf| should not create instances of this class directly.
 
-        Use |DwfLibrary.deviceControl.open:link| or |pydwf.utilities.open_dwf_device:link| to obtain a valid
+        Use |DeviceControl.open:link| or |pydwf.utilities.openDwfDevice:link| to obtain a valid
         |DwfDevice| instance.
 
     The main test and measurement functionality of a Digilent Waveforms device is provided as
@@ -274,7 +274,7 @@ class DwfDevice:
         Raises:
             DwfLibraryError: The trigger source cannot be retrieved.
         """
-        c_trigger_source = typespec_ctypes.TRIGSRC()
+        c_trigger_source = typespec_ctypes.DwfTriggerSource()
         result = self.lib.FDwfDeviceTriggerGet(self.hdwf, pin_index, c_trigger_source)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -308,11 +308,11 @@ class DwfDevice:
         slope_list = [slope for slope in DwfTriggerSlope if slope_bitset & (1 << slope.value)]
         return slope_list
 
-    def paramSet(self, parameter: DwfParameter, value: int) -> None:
+    def paramSet(self, parameter: DwfDeviceParameter, value: int) -> None:
         """Set a device parameter.
 
         Parameters:
-            parameter (DwfParameter): The device parameter to set.
+            parameter (DwfDeviceParameter): The device parameter to set.
             value (int): The value to assign to the parameter.
 
         Raises:
@@ -322,11 +322,11 @@ class DwfDevice:
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def paramGet(self, parameter: DwfParameter) -> int:
+    def paramGet(self, parameter: DwfDeviceParameter) -> int:
         """Retrieve a device parameter.
 
         Parameters:
-            parameter (DwfParameter): The device parameter to retrieve.
+            parameter (DwfDeviceParameter): The device parameter to retrieve.
 
         Returns:
             int: The integer value of the parameter.
